Find the year of the last approved use of an active substance
Source:R/last_approved.R
last_approved.RdFind the year of the last approved use of an active substance
Usage
last_approved(pattern, lang = c("de", "fr", "it"))Arguments
- pattern
Search pattern for the substance name, passed to grepl.
- lang
Should the German names be searched in (default), or the French or the Italian ones?
Value
A tibble containing the matched substance names and the latest occurrence in srppp_active_substances_merged.